document.addEventListener('DOMContentLoaded', function() {
  const t1Input = document.getElementById('t1-input');
  const t2Input = document.getElementById('t2-input');
  const t1Preview = document.getElementById('t1-preview');
  const t2Preview = document.getElementById('t2-preview');
  const processBtn = document.getElementById('process-btn');
  const outputPreview = document.getElementById('output-preview');
  
  function updatePreview(file, previewElement) {
    if (file) {
      previewElement.innerHTML = `
        <div class="file-info">
          <p><strong>File:</strong> ${file.name}</p>
          <p><strong>Size:</strong> ${(file.size / 1024 / 1024).toFixed(2)} MB</p>
        </div>
      `;
    } else {
      previewElement.innerHTML = '<p>No file selected</p>';
    }
  }

  t1Input.addEventListener('change', (e) => {
    updatePreview(e.target.files[0], t1Preview);
  });

  t2Input.addEventListener('change', (e) => {
    updatePreview(e.target.files[0], t2Preview);
  });

  processBtn.addEventListener('click', async () => {
    if (!t1Input.files[0] || !t2Input.files[0]) {
      alert('Please upload both T1 and T2 images');
      return;
    }

    processBtn.disabled = true;
    processBtn.textContent = 'Processing...';

    try {
      // Simulate processing delay
      await new Promise(resolve => setTimeout(resolve, 2000));
      
      outputPreview.innerHTML = `
        <div class="success-message">
          <h4>Processing Complete!</h4>
          <p>Enhanced T2w image generated successfully.</p>
          <button class="process-button" onclick="alert('Download starting...')">
            Download Result
          </button>
        </div>
      `;
    } catch (error) {
      outputPreview.innerHTML = `
        <div class="error-message">
          <p>Error processing images. Please try again.</p>
        </div>
      `;
    } finally {
      processBtn.disabled = false;
      processBtn.textContent = 'Process Images';
    }
  });
});
